.. image:: _static/header.png
    :align: center

:literal:`Solcore` was born as a modular set of tools, written (almost) entirely in Python 3, to address some of the task we had to solve more often, such as fitting dark IV curves or luminescence decays. With time, however,  it has evolved as a complete semiconductor solver able of modelling the optical and electrical properties of a wide range of solar cells, from quantum well devices to multi-junction solar cells. A compact description of Solcore's functionality and physics can be found in the open access publication:

`D. Alonso-Álvarez, T. Wilson, P. Pearce, M. Führer, D. Farrell, N. Ekins-Daukes, Journal of Computational Electronics (2018) <https://doi.org/10.1007/s10825-018-1171-3>`_.

Please, cite this article if you find Solcore useful for your research.

.. image:: Infographics.jpg
    :align: center


Contents:
---------

.. toctree::
    :maxdepth: 2

    Installation/installation
    Structures/structure
    Systems/systems
    QM/Schrodinger
    spectral/spectral
    Optics/optics
    Solvers/solving_solar_cells
    Quasi3D/spice
    Examples/main

.. Indices and tables
.. ==================
..
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

